# Easy-Graph
https://easy-graph.github.io/

EasyGraph is an open source graph processing library. It is written in Python and supports analysis for undirected graphs and directed graphs. 
It covers advanced graph processing methods in structural hole spanners detection, graph embedding and several classic methods (subgraph 
generation, connected component discovery and isomorphic graph generation). 

EasyGraph integrates state-of-the-art graph processing approaches and implements them using Python. EasyGraph covers a series of advanced graph 
processing algorithms include structural hole spanners detection (HIS, MaxD, Common_Greedy, AP_Greedy and HAM), and graph representation learning 
(DeepWalk, Node2Vec, LINE and SDNE). Besides, for a number of general graph processing approaches, EasyGraph optimizes the algorithms and introduces 
parallel computing methods to achieve high efficiency.
